==> 0.0.3.tar.gz: lib/CreateOrderRequest.dart <==
class CreateOrderRequest {

  int accountID;
  Order order;

  CreateOrderRequest({this.accountID, this.order});

  CreateOrderRequest.fromJson(Map<String, dynamic> json) {
    accountID = json['accountID'];
    order = json['order'] != null ? new Order.fromJson(json['order']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['accountID'] = this.accountID;
    if (this.order != null) {
      data['order'] = this.order.toJson();
    }
    return data;
  }
}

class Order {
  int accountId;
  Customer customer;
  DeliveryInfo deliveryInfo;
  List<Product> products;
  String status;


  Order(
      {this.accountId,
        this.customer,
        this.deliveryInfo,
        this.products,
        this.status});

  Order.fromJson(Map<String, dynamic> json) {
    accountId = json['accountId'];
    customer = json['customer'] != null
        ? new Customer.fromJson(json['customer'])
        : null;
    deliveryInfo = json['deliveryInfo'] != null
        ? new DeliveryInfo.fromJson(json['deliveryInfo'])
        : null;

    if (json['products'] != null) {
      products = new List<Product>();
      json['products'].forEach((v) {
        products.add(new Product.fromJson(v));
      });
    }
    status = json['status'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['accountId'] = this.accountId;
    if (this.customer != null) {
      data['customer'] = this.customer.toJson();
    }
    if (this.deliveryInfo != null) {
      data['deliveryInfo'] = this.deliveryInfo.toJson();
    }
    if (this.products != null) {
      data['products'] =
          this.products.map((v) => v.toJson()).toList();
    }
    data['status'] = this.status;
    return data;
  }
}

class Customer {
  String fullName;
  String phoneNumber;
  String address;
  String location;
  String landmark;


  Customer({this.fullName, this.phoneNumber, this.address,this.location, this.landmark});

  Customer.fromJson(Map<String, dynamic> json) {
    fullName = json['fullName'];
    phoneNumber = json['phoneNumber'];
    address = json['address'];
    location= json['location'];
    landmark=json['landmark'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fullName'] = this.fullName;
    data['phoneNumber'] = this.phoneNumber;
    data['address'] = this.address;
    data['location']= this.location;
    data['landmark']= this.landmark;
    return data;
  }
}

class DeliveryInfo {
  int cost;

  DeliveryInfo({this.cost});

  DeliveryInfo.fromJson(Map<String, dynamic> json) {
    cost = json['cost'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['cost'] = this.cost;
    return data;
  }
}



class Product {
  String productSKU;
  int profitMargin;
  int price;
  int quantity;
  String status;
  String promoId;

  Product(this.productSKU, this.profitMargin, this.price, this.quantity,
      this.status, this.promoId);

  Product.fromJson(Map<String, dynamic> json){
    productSKU= json['productSKU'];
    profitMargin= json['profitMargin'];
    price=json['price'];
    quantity=json['quantity'];
    status=json['status'];
    promoId=json['promoId'];
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['productSKU'] = this.productSKU;
    data['profitMargin'] = this.profitMargin;
    data['price']=this.price;
    data['quantity']=this.quantity;
    data['status']=this.status;
    data['promoId']=this.promoId;
    return data;
  }

}

==> 0.0.6.tar.gz: lib/CreateOrderRequest.dart <==
class CreateOrderRequest {

  int accountID;
  Order order;

  CreateOrderRequest({this.accountID, this.order});

  CreateOrderRequest.fromJson(Map<String, dynamic> json) {
    accountID = json['accountID'];
    order = json['order'] != null ? new Order.fromJson(json['order']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['accountID'] = this.accountID;
    if (this.order != null) {
      data['order'] = this.order.toJson();
    }
    return data;
  }
}

class Order {
  int accountId;
  Customer customer;
  DeliveryInfo deliveryInfo;
  List<Product> products;
  String status;
  String variation;
  String productName;
  String comment;


  Order(
      {this.accountId,
        this.customer,
        this.deliveryInfo,
        this.products,
        this.status,
      this.variation,
      this.productName,
      this.comment});

  Order.fromJson(Map<String, dynamic> json) {
    accountId = json['accountId'];
    customer = json['customer'] != null
        ? new Customer.fromJson(json['customer'])
        : null;
    deliveryInfo = json['deliveryInfo'] != null
        ? new DeliveryInfo.fromJson(json['deliveryInfo'])
        : null;

    if (json['products'] != null) {
      products = new List<Product>();
      json['products'].forEach((v) {
        products.add(new Product.fromJson(v));
      });
    }
    status = json['status'];
    variation = json['variation'];
    productName = json['productName'];
    comment = json['comment'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['accountId'] = this.accountId;
    if (this.customer != null) {
      data['customer'] = this.customer.toJson();
    }
    if (this.deliveryInfo != null) {
      data['deliveryInfo'] = this.deliveryInfo.toJson();
    }
    if (this.products != null) {
      data['products'] =
          this.products.map((v) => v.toJson()).toList();
    }
    data['status'] = this.status;
    data['variation'] = this.variation;
    data['productName'] = this.productName;
    data['comment'] = this.comment;
    return data;
  }
}

class Customer {
  String fullName;
  String phoneNumber;
  String location;
  String landmark;


  Customer({this.fullName, this.phoneNumber, this.location, this.landmark});

  Customer.fromJson(Map<String, dynamic> json) {
    fullName = json['fullName'];
    phoneNumber = json['phoneNumber'];
    location= json['location'];
    landmark=json['landmark'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['fullName'] = this.fullName;
    data['phoneNumber'] = this.phoneNumber;
    data['location']= this.location;
    data['landmark']= this.landmark;
    return data;
  }
}

class DeliveryInfo {
  int cost;

  DeliveryInfo({this.cost});

  DeliveryInfo.fromJson(Map<String, dynamic> json) {
    cost = json['cost'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['cost'] = this.cost;
    return data;
  }
}



class Product {
  String productSKU;
  int profitMargin;
  int price;
  int quantity;
  String status;
  String promoId;

  Product(this.productSKU, this.profitMargin, this.price, this.quantity,
      this.status, this.promoId);

  Product.fromJson(Map<String, dynamic> json){
    productSKU= json['productSKU'];
    profitMargin= json['profitMargin'];
    price=json['price'];
    quantity=json['quantity'];
    status=json['status'];
    promoId=json['promoId'];
  }
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['productSKU'] = this.productSKU;
    data['profitMargin'] = this.profitMargin;
    data['price']=this.price;
    data['quantity']=this.quantity;
    data['status']=this.status;
    data['promoId']=this.promoId;
    return data;
  }

}
